@@ -7,6 +7,7 @@ import tempfile
 import ipywidgets
 import numpy as np
 import discretisedfield as df
+import matplotlib.pyplot as plt
 
 
 def check_mesh(mesh):
@@ -22,9 +23,7 @@ def check_mesh(mesh):
     assert all(isinstance(i, int) for i in mesh.n)
     assert all(i > 0 for i in mesh.n)
 
-    assert isinstance(mesh.pbc, set)
-    assert all(isinstance(i, str) for i in mesh.pbc)
-    assert all(i in 'xyz' for i in mesh.pbc)
+    assert isinstance(mesh.bc, str)
 
     assert isinstance(mesh.subregions, dict)
     assert all(isinstance(i, str) for i in mesh.subregions.keys())
@@ -131,16 +130,6 @@ class TestMesh:
             with pytest.raises((TypeError, ValueError)):
                 mesh = df.Mesh(p1=p1, p2=p2, n=n, cell=cell)
 
-    def test_init_pbc(self):
-        for p1, p2, n, cell in self.valid_args:
-            for pbc in ['x', 'z', 'zx', 'xyxzz', 'yz', 'yy']:
-                mesh = df.Mesh(p1=p1, p2=p2, n=n, cell=cell, pbc=pbc)
-                check_mesh(mesh)
-                assert mesh.pbc == set(pbc)
-            for pbc in ['abc', 'a', '123', 5, -3]:
-                with pytest.raises((ValueError, TypeError)):
-                    mesh = df.Mesh(p1=p1, p2=p2, n=n, cell=cell, pbc=pbc)
-
     def test_init_subregions(self):
         p1 = (0, 0, 0)
         p2 = (100, 50, 10)
@@ -259,12 +248,12 @@ class TestMesh:
         p2 = (15, 10.1, 12.5)
         cell = (1, 0.1, 0.5)
 
-        mesh = df.Mesh(p1=p1, p2=p2, cell=cell, pbc='x')
+        mesh = df.Mesh(p1=p1, p2=p2, cell=cell, bc='x')
         check_mesh(mesh)
 
         rstr = ('Mesh(region=Region(p1=(-1.0, -4.0, 11.0), '
                 'p2=(15.0, 10.1, 12.5)), n=(16, 141, 3), '
-                'pbc={\'x\'}, subregions={})')
+                'bc=\'x\', subregions={})')
         assert repr(mesh) == rstr
 
     def test_index2point(self):
@@ -380,7 +369,7 @@ class TestMesh:
         p1 = (0, 0, 0)
         p2 = (5, 5, 5)
         n = (5, 5, 5)
-        mesh = df.Mesh(region=df.Region(p1=p1, p2=p2), n=n, pbc='xy')
+        mesh = df.Mesh(region=df.Region(p1=p1, p2=p2), n=n, bc='xy')
 
         neighbours = mesh.neighbours((0, 0, 0))
         assert isinstance(neighbours, list)
@@ -572,6 +561,33 @@ class TestMesh:
 
         assert len(submesh1) + len(submesh2) == len(mesh)
 
+    def test_pad(self):
+        p1 = (-1, 2, 7)
+        p2 = (5, 9, 4)
+        cell = (1, 1, 1)
+        region = df.Region(p1=p1, p2=p2)
+        mesh = df.Mesh(region=region, cell=cell)
+
+        padded_mesh = mesh.pad({'x': (0, 1)})
+        assert padded_mesh.region.pmin == (-1, 2, 4)
+        assert padded_mesh.region.pmax == (6, 9, 7)
+        assert padded_mesh.n == (7, 7, 3)
+
+        padded_mesh = mesh.pad({'y': (1, 1)})
+        assert padded_mesh.region.pmin == (-1, 1, 4)
+        assert padded_mesh.region.pmax == (5, 10, 7)
+        assert padded_mesh.n == (6, 9, 3)
+
+        padded_mesh = mesh.pad({'z': (2, 3)})
+        assert padded_mesh.region.pmin == (-1, 2, 2)
+        assert padded_mesh.region.pmax == (5, 9, 10)
+        assert padded_mesh.n == (6, 7, 8)
+
+        padded_mesh = mesh.pad({'x': (1, 1), 'y': (1, 1), 'z': (1, 1)})
+        assert padded_mesh.region.pmin == (-2, 1, 3)
+        assert padded_mesh.region.pmax == (6, 10, 8)
+        assert padded_mesh.n == (8, 9, 5)
+
     def test_mpl(self):
         for p1, p2, n, cell in self.valid_args:
             mesh = df.Mesh(region=df.Region(p1=p1, p2=p2), n=n, cell=cell)
@@ -582,18 +598,14 @@ class TestMesh:
                 tmpfilename = os.path.join(tmpdir, filename)
                 mesh.mpl(filename=tmpfilename)
 
+            plt.close('all')
+
     def test_k3d(self):
         for p1, p2, n, cell in self.valid_args:
             mesh = df.Mesh(p1=p1, p2=p2, n=n, cell=cell)
             mesh.k3d()
             mesh.plane('x').k3d()
 
-    def test_k3d_points(self):
-        for p1, p2, n, cell in self.valid_args:
-            mesh = df.Mesh(p1=p1, p2=p2, n=n, cell=cell)
-            mesh.k3d_points()
-            mesh.plane('y').k3d_points()
-
     def test_k3d_mpl_subregions(self):
         p1 = (0, 0, 0)
         p2 = (100, 80, 10)
@@ -607,7 +619,18 @@ class TestMesh:
                       'r7': df.Region(p1=(0, 60, 0), p2=(100, 70, 10)),
                       'r8': df.Region(p1=(0, 70, 0), p2=(100, 80, 10))}
         mesh = df.Mesh(p1=p1, p2=p2, cell=cell, subregions=subregions)
+
+        # matplotlib tests
         mesh.mpl_subregions()
+
+        filename = 'figure.pdf'
+        with tempfile.TemporaryDirectory() as tmpdir:
+            tmpfilename = os.path.join(tmpdir, filename)
+            mesh.mpl_subregions(filename=tmpfilename)
+
+        plt.close('all')
+
+        # k3d tests
         mesh.k3d_subregions()
 
     def test_slider(self):
@@ -626,21 +649,21 @@ class TestMesh:
         z_slider = mesh.slider('z', multiplier=1e3)
         assert isinstance(x_slider, ipywidgets.SelectionSlider)
 
-    def test_axis_selection(self):
+    def test_axis_selector(self):
         p1 = (-10e-9, -5e-9, 10e-9)
         p2 = (10e-9, 5e-9, 0)
         cell = (1e-9, 2.5e-9, 1e-9)
         mesh = df.Mesh(p1=p1, p2=p2, cell=cell)
         check_mesh(mesh)
 
-        axis_widget = mesh.axis_selection()
+        axis_widget = mesh.axis_selector()
         assert isinstance(axis_widget, ipywidgets.Dropdown)
 
-        axis_widget = mesh.axis_selection(widget='radiobuttons')
+        axis_widget = mesh.axis_selector(widget='radiobuttons')
         assert isinstance(axis_widget, ipywidgets.RadioButtons)
 
-        axis_widget = mesh.axis_selection(description='something')
+        axis_widget = mesh.axis_selector(description='something')
         assert isinstance(axis_widget, ipywidgets.Dropdown)
 
         with pytest.raises(ValueError):
-            axis_widget = mesh.axis_selection(widget='something')
+            axis_widget = mesh.axis_selector(widget='something')
